@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "qtcprocess.h"
 #include "stringutils.h"
@@ -206,11 +203,11 @@ static QStringList doSplitArgs(const QString &args, QtcProcess::SplitError *err)
 
     The behavior is based on the POSIX shell and bash:
     \list
-    \i Whitespace splits tokens
-    \i The backslash quotes the following character
-    \i A string enclosed in single quotes is not split. No shell meta
+    \li Whitespace splits tokens
+    \li The backslash quotes the following character
+    \li A string enclosed in single quotes is not split. No shell meta
         characters are interpreted.
-    \i A string enclosed in double quotes is not split. Within the string,
+    \li A string enclosed in double quotes is not split. Within the string,
         the backslash quotes shell meta characters - if it is followed
         by a "meaningless" character, the backslash is output verbatim.
     \endlist
@@ -223,16 +220,16 @@ static QStringList doSplitArgs(const QString &args, QtcProcess::SplitError *err)
 
     The behavior is defined by the Microsoft C runtime:
     \list
-    \i Whitespace splits tokens
-    \i A string enclosed in double quotes is not split
+    \li Whitespace splits tokens
+    \li A string enclosed in double quotes is not split
     \list
-        \i 3N double quotes within a quoted string yield N literal quotes.
+        \li 3N double quotes within a quoted string yield N literal quotes.
            This is not documented on MSDN.
     \endlist
-    \i Backslashes have special semantics iff they are followed by a double quote:
+    \li Backslashes have special semantics iff they are followed by a double quote:
     \list
-        \i 2N backslashes + double quote => N backslashes and begin/end quoting
-        \i 2N+1 backslashes + double quote => N backslashes + literal quote
+        \li 2N backslashes + double quote => N backslashes and begin/end quoting
+        \li 2N+1 backslashes + double quote => N backslashes + literal quote
     \endlist
     \endlist
     Qt and many other implementations comply with this standard, but many do not.
@@ -240,10 +237,10 @@ static QStringList doSplitArgs(const QString &args, QtcProcess::SplitError *err)
     If \a abortOnMeta is \c true, cmd shell semantics are applied before
     proceeding with word splitting:
     \list
-    \i Cmd ignores \e all special chars between double quotes.
+    \li Cmd ignores \e all special chars between double quotes.
         Note that the quotes are \e not removed at this stage - the
         tokenization rules described above still apply.
-    \i The \c circumflex is the escape char for everything including itself.
+    \li The \c circumflex is the escape char for everything including itself.
     \endlist
     As the quoting levels are independent from each other and have different
     semantics, you need a command line like \c{"foo "\^"" bar"} to get
@@ -281,7 +278,7 @@ QStringList QtcProcess::splitArgs(const QString &_args, bool abortOnMeta, SplitE
 
 inline static bool isQuoteMeta(QChar cUnicode)
 {
-    char c = cUnicode.toAscii();
+    char c = cUnicode.toLatin1();
     return c == '\\' || c == '\'' || c == '"' || c == '$';
 }
 
