@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -37,8 +37,8 @@
 
 #include <projectexplorer/project.h>
 #include <projectexplorer/projectnodes.h>
-#include <projectexplorer/buildstep.h>
 #include <projectexplorer/buildconfiguration.h>
+#include <projectexplorer/namedwidget.h>
 #include <coreplugin/idocument.h>
 #include <coreplugin/editormanager/editormanager.h>
 #include <coreplugin/editormanager/ieditor.h>
@@ -85,19 +85,17 @@ public:
     Core::IDocument *document() const;
     CMakeManager *projectManager() const;
 
-    QList<ProjectExplorer::BuildConfigWidget*> subConfigWidgets();
-
     ProjectExplorer::ProjectNode *rootProjectNode() const;
 
     QStringList files(FilesMode fileMode) const;
-    QStringList buildTargetTitles() const;
+    QStringList buildTargetTitles(bool runnable = false) const;
     QList<CMakeBuildTarget> buildTargets() const;
     bool hasBuildTarget(const QString &title) const;
 
     CMakeBuildTarget buildTargetForTitle(const QString &title);
 
-    QString defaultBuildDirectory() const;
-
+    QString shadowBuildDirectory(const QString &projectFilePath, const ProjectExplorer::Kit *k,
+                                 const QString &bcName);
 
     QString uicCommand() const;
 
@@ -176,7 +174,7 @@ private:
     void parseOption();
     void parseBuildTarget();
     void parseBuildTargetOption();
-    void parseMakeCommand();
+    void parseMakeCommands();
     void parseBuildTargetBuild();
     void parseBuildTargetClean();
     void parseCompiler();
@@ -194,7 +192,6 @@ private:
     QByteArray m_defines;
 
     CMakeBuildTarget m_buildTarget;
-    bool m_buildTargetType;
     QList<CMakeBuildTarget> m_buildTargets;
     QString m_projectName;
     QString m_compiler;
@@ -226,15 +223,11 @@ private:
     QString m_fileName;
 };
 
-class CMakeBuildSettingsWidget : public ProjectExplorer::BuildConfigWidget
+class CMakeBuildSettingsWidget : public ProjectExplorer::NamedWidget
 {
     Q_OBJECT
 public:
-    CMakeBuildSettingsWidget();
-    QString displayName() const;
-
-    // This is called to set up the config widget before showing it
-    void init(ProjectExplorer::BuildConfiguration *bc);
+    CMakeBuildSettingsWidget(CMakeBuildConfiguration *bc);
 
 private slots:
     void openChangeBuildDirectoryDialog();
