@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "outputparser_test.h"
 #include "task.h"
@@ -61,7 +58,7 @@ void OutputParserTester::testParsing(const QString &lines,
     reset();
     Q_ASSERT(childParser());
 
-    QStringList inputLines = lines.split(QChar('\n'));
+    QStringList inputLines = lines.split(QLatin1Char('\n'));
     foreach (const QString &input, inputLines) {
         if (inputChannel == STDOUT)
             childParser()->stdOutput(input + QLatin1Char('\n'));
@@ -87,7 +84,7 @@ void OutputParserTester::testParsing(const QString &lines,
     QCOMPARE(m_receivedStdOutChildLine, childStdOutLines);
     QCOMPARE(m_receivedTasks.size(), tasks.size());
     if (m_receivedTasks.size() == tasks.size()) {
-        for(int i = 0; i < tasks.size(); ++i) {
+        for (int i = 0; i < tasks.size(); ++i) {
             QCOMPARE(m_receivedTasks.at(i).category, tasks.at(i).category);
             QCOMPARE(m_receivedTasks.at(i).description, tasks.at(i).description);
             QCOMPARE(m_receivedTasks.at(i).file, tasks.at(i).file);
@@ -158,7 +155,7 @@ void OutputParserTester::outputAdded(const QString &line, ProjectExplorer::Build
 {
     Q_UNUSED(format);
     if (!m_receivedOutput.isEmpty())
-        m_receivedOutput.append(QChar('\n'));
+        m_receivedOutput.append(QLatin1Char('\n'));
     m_receivedOutput.append(line);
 }
 
