@@ -1,48 +1,41 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "nodeinstanceview.h"
 
-#include <QDeclarativeEngine>
-#include <QDeclarativeContext>
-#include <private/qdeclarativeengine_p.h>
-
-#include <QtDebug>
 #include <QUrl>
 #include <QGraphicsView>
 #include <QGraphicsScene>
 #include <QGraphicsObject>
 #include <QFileSystemWatcher>
 #include <QMultiHash>
+#include <QTimer>
 
 #include <model.h>
 #include <modelnode.h>
@@ -81,6 +74,7 @@
 #include "completecomponentcommand.h"
 #include "componentcompletedcommand.h"
 #include "tokencommand.h"
+#include "removesharedmemorycommand.h"
 
 #include "nodeinstanceserverproxy.h"
 
@@ -117,9 +111,13 @@ d too.
 NodeInstanceView::NodeInstanceView(QObject *parent, NodeInstanceServerInterface::RunModus runModus)
         : AbstractView(parent),
           m_baseStatePreviewImage(QSize(100, 100), QImage::Format_ARGB32),
-          m_runModus(runModus)
+          m_runModus(runModus),
+          m_puppetRestarted(false)
 {
     m_baseStatePreviewImage.fill(0xFFFFFF);
+    m_singleShotTimerRestartProcessDelayed.setSingleShot(true);
+    m_singleShotTimerRestartProcessDelayed.setInterval(400);
+    connect(&m_singleShotTimerRestartProcessDelayed, SIGNAL(timeout()), this, SLOT(restartProcessDelayedTimeOut()));
 }
 
 
@@ -198,17 +196,21 @@ void NodeInstanceView::handleChrash()
 {
     int elaspsedTimeSinceLastCrash = m_lastCrashTime.restart();
 
-    if (elaspsedTimeSinceLastCrash > 2000) {
+    if (elaspsedTimeSinceLastCrash > 2000)
         restartProcess();
-    } else {
+    else
         emit  qmlPuppetCrashed();
-    }
 }
 
-
+void NodeInstanceView::restartProcessDelayedTimeOut()
+{
+    if (!m_puppetRestarted)
+        restartProcess();
+}
 
 void NodeInstanceView::restartProcess()
 {
+    m_puppetRestarted = true;
     if (model()) {
         delete nodeInstanceServer();
 
@@ -226,6 +228,12 @@ void NodeInstanceView::restartProcess()
     }
 }
 
+void NodeInstanceView::restartProcessDelayed()
+{
+    m_puppetRestarted = false;
+    m_singleShotTimerRestartProcessDelayed.start();
+}
+
 void NodeInstanceView::nodeCreated(const ModelNode &createdNode)
 {
     NodeInstance instance = loadNode(createdNode);
@@ -244,6 +252,7 @@ void NodeInstanceView::nodeCreated(const ModelNode &createdNode)
 void NodeInstanceView::nodeAboutToBeRemoved(const ModelNode &removedNode)
 {
     nodeInstanceServer()->removeInstances(createRemoveInstancesCommand(removedNode));
+    nodeInstanceServer()->removeSharedMemory(createRemoveSharedMemoryCommand("Image", removedNode.internalId()));
     removeInstanceAndSubInstances(removedNode);
 }
 
@@ -256,17 +265,15 @@ void NodeInstanceView::resetHorizontalAnchors(const ModelNode &modelNode)
     QList<BindingProperty> bindingList;
     QList<VariantProperty> valueList;
 
-    if (modelNode.hasBindingProperty("x")) {
+    if (modelNode.hasBindingProperty("x"))
         bindingList.append(modelNode.bindingProperty("x"));
-    } else if (modelNode.hasVariantProperty("x")) {
+    else if (modelNode.hasVariantProperty("x"))
         valueList.append(modelNode.variantProperty("x"));
-    }
 
-    if (modelNode.hasBindingProperty("width")) {
+    if (modelNode.hasBindingProperty("width"))
         bindingList.append(modelNode.bindingProperty("width"));
-    } else if (modelNode.hasVariantProperty("width")) {
+    else if (modelNode.hasVariantProperty("width"))
         valueList.append(modelNode.variantProperty("width"));
-    }
 
     if (!valueList.isEmpty())
         nodeInstanceServer()->changePropertyValues(createChangeValueCommand(valueList));
@@ -281,17 +288,15 @@ void NodeInstanceView::resetVerticalAnchors(const ModelNode &modelNode)
     QList<BindingProperty> bindingList;
     QList<VariantProperty> valueList;
 
-    if (modelNode.hasBindingProperty("yx")) {
+    if (modelNode.hasBindingProperty("yx"))
         bindingList.append(modelNode.bindingProperty("yx"));
-    } else if (modelNode.hasVariantProperty("y")) {
+    else if (modelNode.hasVariantProperty("y"))
         valueList.append(modelNode.variantProperty("y"));
-    }
 
-    if (modelNode.hasBindingProperty("height")) {
+    if (modelNode.hasBindingProperty("height"))
         bindingList.append(modelNode.bindingProperty("height"));
-    } else if (modelNode.hasVariantProperty("height")) {
+    else if (modelNode.hasVariantProperty("height"))
         valueList.append(modelNode.variantProperty("height"));
-    }
 
     if (!valueList.isEmpty())
         nodeInstanceServer()->changePropertyValues(createChangeValueCommand(valueList));
@@ -307,14 +312,14 @@ void NodeInstanceView::propertiesAboutToBeRemoved(const QList<AbstractProperty>&
     QList<AbstractProperty> nonNodePropertyList;
 
     foreach (const AbstractProperty &property, propertyList) {
-        if (property.isNodeAbstractProperty()) {
+        if (property.isNodeAbstractProperty())
             nodeList.append(property.toNodeAbstractProperty().allSubNodes());
-        } else {
+        else
             nonNodePropertyList.append(property);
-        }
     }
 
     nodeInstanceServer()->removeInstances(createRemoveInstancesCommand(nodeList));
+    nodeInstanceServer()->removeSharedMemory(createRemoveSharedMemoryCommand("Image", nodeList));
     nodeInstanceServer()->removeProperties(createRemovePropertiesCommand(nonNodePropertyList));
 
     foreach (const AbstractProperty &property, propertyList) {
@@ -352,7 +357,7 @@ void NodeInstanceView::propertiesRemoved(const QList<AbstractProperty>& /*proper
 
 void NodeInstanceView::removeInstanceAndSubInstances(const ModelNode &node)
 {
-    foreach(const ModelNode &subNode, node.allSubModelNodes()) {
+    foreach (const ModelNode &subNode, node.allSubModelNodes()) {
         if (hasInstanceForNode(subNode))
             removeInstanceNodeRelationship(subNode);
     }
@@ -432,7 +437,7 @@ void NodeInstanceView::nodeOrderChanged(const NodeListProperty & listProperty,
     if (hasInstanceForNode(containerNode))
         containerInstanceId = instanceForNode(containerNode).instanceId();
 
-    foreach(const ModelNode &node, listProperty.toModelNodeList()) {
+    foreach (const ModelNode &node, listProperty.toModelNodeList()) {
         qint32 instanceId = -1;
         if (hasInstanceForNode(node)) {
             instanceId = instanceForNode(node).instanceId();
@@ -556,11 +561,10 @@ void NodeInstanceView::actualStateChanged(const ModelNode &node)
 {
     NodeInstance newStateInstance = instanceForNode(node);
 
-    if (newStateInstance.isValid() && node.metaInfo().isSubclassOf("QtQuick.State", 1, 0)) {
+    if (newStateInstance.isValid() && node.metaInfo().isSubclassOf("QtQuick.State", 1, 0))
         nodeInstanceView()->activateState(newStateInstance);
-    } else {
+    else
         nodeInstanceView()->activateBaseState();
-    }
 }
 
 
@@ -662,7 +666,7 @@ NodeInstance NodeInstanceView::rootNodeInstance() const
 void NodeInstanceView::insertInstanceRelationships(const NodeInstance &instance)
 {
     Q_ASSERT(instance.instanceId() >=0);
-    if(m_nodeInstanceHash.contains(instance.modelNode()))
+    if (m_nodeInstanceHash.contains(instance.modelNode()))
         return;
 
     m_nodeInstanceHash.insert(instance.modelNode(), instance);
@@ -703,9 +707,8 @@ NodeInstance NodeInstanceView::loadNode(const ModelNode &node)
 
     insertInstanceRelationships(instance);
 
-    if (node.isRootNode()) {
+    if (node.isRootNode())
         m_rootNodeInstance = instance;
-    }
 
     return instance;
 }
@@ -743,7 +746,7 @@ QRectF NodeInstanceView::sceneRect() const
 QList<ModelNode> filterNodesForSkipItems(const QList<ModelNode> &nodeList)
 {
     QList<ModelNode> filteredNodeList;
-    foreach(const ModelNode &node, nodeList) {
+    foreach (const ModelNode &node, nodeList) {
         if (isSkippedNode(node))
             continue;
 
@@ -767,7 +770,7 @@ CreateSceneCommand NodeInstanceView::createCreateSceneCommand()
     nodeList = filterNodesForSkipItems(nodeList);
 
     QList<VariantProperty> variantPropertyList;
-    QList<BindingProperty> bindingPropertyList;    
+    QList<BindingProperty> bindingPropertyList;
 
     QVector<PropertyValueContainer> auxiliaryContainerVector;
     foreach (const ModelNode &node, nodeList) {
@@ -786,7 +789,7 @@ CreateSceneCommand NodeInstanceView::createCreateSceneCommand()
 
 
     QVector<InstanceContainer> instanceContainerList;
-    foreach(const NodeInstance &instance, instanceList) {
+    foreach (const NodeInstance &instance, instanceList) {
         InstanceContainer::NodeSourceType nodeSourceType = static_cast<InstanceContainer::NodeSourceType>(instance.modelNode().nodeSourceType());
 
         InstanceContainer::NodeMetaType nodeMetaType = InstanceContainer::ObjectMetaType;
@@ -807,7 +810,7 @@ CreateSceneCommand NodeInstanceView::createCreateSceneCommand()
     }
 
     QVector<ReparentContainer> reparentContainerList;
-    foreach(const NodeInstance &instance, instanceList) {
+    foreach (const NodeInstance &instance, instanceList) {
         if (instance.modelNode().hasParentProperty()) {
             NodeAbstractProperty parentProperty = instance.modelNode().parentProperty();
             ReparentContainer container(instance.instanceId(), -1, QString(), instanceForNode(parentProperty.parentModelNode()).instanceId(), parentProperty.name());
@@ -816,7 +819,7 @@ CreateSceneCommand NodeInstanceView::createCreateSceneCommand()
     }
 
     QVector<IdContainer> idContainerList;
-    foreach(const NodeInstance &instance, instanceList) {
+    foreach (const NodeInstance &instance, instanceList) {
         QString id = instance.modelNode().id();
         if (!id.isEmpty()) {
             IdContainer container(instance.instanceId(), id);
@@ -825,7 +828,7 @@ CreateSceneCommand NodeInstanceView::createCreateSceneCommand()
     }
 
     QVector<PropertyValueContainer> valueContainerList;
-    foreach(const VariantProperty &property, variantPropertyList) {
+    foreach (const VariantProperty &property, variantPropertyList) {
         ModelNode node = property.parentModelNode();
         if (node.isValid() && hasInstanceForNode(node)) {
             NodeInstance instance = instanceForNode(node);
@@ -835,7 +838,7 @@ CreateSceneCommand NodeInstanceView::createCreateSceneCommand()
     }
 
     QVector<PropertyBindingContainer> bindingContainerList;
-    foreach(const BindingProperty &property, bindingPropertyList) {
+    foreach (const BindingProperty &property, bindingPropertyList) {
         ModelNode node = property.parentModelNode();
         if (node.isValid() && hasInstanceForNode(node)) {
             NodeInstance instance = instanceForNode(node);
@@ -845,7 +848,7 @@ CreateSceneCommand NodeInstanceView::createCreateSceneCommand()
     }
 
     QVector<AddImportContainer> importVector;
-    foreach(const Import &import, model()->imports())
+    foreach (const Import &import, model()->imports())
         importVector.append(AddImportContainer(import.url(), import.file(), import.version(), import.alias(), import.importPaths()));
 
     return CreateSceneCommand(instanceContainerList,
@@ -866,7 +869,7 @@ ClearSceneCommand NodeInstanceView::createClearSceneCommand() const
 CompleteComponentCommand NodeInstanceView::createComponentCompleteCommand(const QList<NodeInstance> &instanceList) const
 {
     QVector<qint32> containerList;
-    foreach(const NodeInstance &instance, instanceList) {
+    foreach (const NodeInstance &instance, instanceList) {
         if (instance.instanceId() >= 0)
             containerList.append(instance.instanceId());
     }
@@ -877,7 +880,7 @@ CompleteComponentCommand NodeInstanceView::createComponentCompleteCommand(const
 ComponentCompletedCommand NodeInstanceView::createComponentCompletedCommand(const QList<NodeInstance> &instanceList) const
 {
     QVector<qint32> containerList;
-    foreach(const NodeInstance &instance, instanceList) {
+    foreach (const NodeInstance &instance, instanceList) {
         if (instance.instanceId() >= 0)
             containerList.append(instance.instanceId());
     }
@@ -888,7 +891,7 @@ ComponentCompletedCommand NodeInstanceView::createComponentCompletedCommand(cons
 CreateInstancesCommand NodeInstanceView::createCreateInstancesCommand(const QList<NodeInstance> &instanceList) const
 {
     QVector<InstanceContainer> containerList;
-    foreach(const NodeInstance &instance, instanceList) {
+    foreach (const NodeInstance &instance, instanceList) {
         InstanceContainer::NodeSourceType nodeSourceType = static_cast<InstanceContainer::NodeSourceType>(instance.modelNode().nodeSourceType());
 
         InstanceContainer::NodeMetaType nodeMetaType = InstanceContainer::ObjectMetaType;
@@ -906,7 +909,7 @@ CreateInstancesCommand NodeInstanceView::createCreateInstancesCommand(const QLis
 ReparentInstancesCommand NodeInstanceView::createReparentInstancesCommand(const QList<NodeInstance> &instanceList) const
 {
     QVector<ReparentContainer> containerList;
-    foreach(const NodeInstance &instance, instanceList) {
+    foreach (const NodeInstance &instance, instanceList) {
         if (instance.modelNode().hasParentProperty()) {
             NodeAbstractProperty parentProperty = instance.modelNode().parentProperty();
             ReparentContainer container(instance.instanceId(), -1, QString(), instanceForNode(parentProperty.parentModelNode()).instanceId(), parentProperty.name());
@@ -948,7 +951,7 @@ ChangeValuesCommand NodeInstanceView::createChangeValueCommand(const QList<Varia
 {
     QVector<PropertyValueContainer> containerList;
 
-    foreach(const VariantProperty &property, propertyList) {
+    foreach (const VariantProperty &property, propertyList) {
         ModelNode node = property.parentModelNode();
         if (node.isValid() && hasInstanceForNode(node)) {
             NodeInstance instance = instanceForNode(node);
@@ -965,7 +968,7 @@ ChangeBindingsCommand NodeInstanceView::createChangeBindingCommand(const QList<B
 {
     QVector<PropertyBindingContainer> containerList;
 
-    foreach(const BindingProperty &property, propertyList) {
+    foreach (const BindingProperty &property, propertyList) {
         ModelNode node = property.parentModelNode();
         if (node.isValid() && hasInstanceForNode(node)) {
             NodeInstance instance = instanceForNode(node);
@@ -981,7 +984,7 @@ ChangeBindingsCommand NodeInstanceView::createChangeBindingCommand(const QList<B
 ChangeIdsCommand NodeInstanceView::createChangeIdsCommand(const QList<NodeInstance> &instanceList) const
 {
     QVector<IdContainer> containerList;
-    foreach(const NodeInstance &instance, instanceList) {
+    foreach (const NodeInstance &instance, instanceList) {
         QString id = instance.modelNode().id();
         if (!id.isEmpty()) {
             IdContainer container(instance.instanceId(), id);
@@ -997,13 +1000,12 @@ ChangeIdsCommand NodeInstanceView::createChangeIdsCommand(const QList<NodeInstan
 RemoveInstancesCommand NodeInstanceView::createRemoveInstancesCommand(const QList<ModelNode> &nodeList) const
 {
     QVector<qint32> idList;
-    foreach(const ModelNode &node, nodeList) {
+    foreach (const ModelNode &node, nodeList) {
         if (node.isValid() && hasInstanceForNode(node)) {
             NodeInstance instance = instanceForNode(node);
 
-            if (instance.instanceId() >= 0) {
+            if (instance.instanceId() >= 0)
                 idList.append(instance.instanceId());
-            }
         }
     }
 
@@ -1024,7 +1026,7 @@ RemovePropertiesCommand NodeInstanceView::createRemovePropertiesCommand(const QL
 {
     QVector<PropertyAbstractContainer> containerList;
 
-    foreach(const AbstractProperty &property, propertyList) {
+    foreach (const AbstractProperty &property, propertyList) {
         ModelNode node = property.parentModelNode();
         if (node.isValid() && hasInstanceForNode(node)) {
             NodeInstance instance = instanceForNode(node);
@@ -1037,6 +1039,21 @@ RemovePropertiesCommand NodeInstanceView::createRemovePropertiesCommand(const QL
     return RemovePropertiesCommand(containerList);
 }
 
+RemoveSharedMemoryCommand NodeInstanceView::createRemoveSharedMemoryCommand(const QString &sharedMemoryTypeName, quint32 keyNumber)
+{
+    return RemoveSharedMemoryCommand(sharedMemoryTypeName, QVector<qint32>() << keyNumber);
+}
+
+RemoveSharedMemoryCommand NodeInstanceView::createRemoveSharedMemoryCommand(const QString &sharedMemoryTypeName, const QList<ModelNode> &nodeList)
+{
+    QVector<qint32> keyNumberVector;
+
+    foreach (const ModelNode &modelNode, nodeList)
+        keyNumberVector.append(modelNode.internalId());
+
+    return RemoveSharedMemoryCommand(sharedMemoryTypeName, keyNumberVector);
+}
+
 void NodeInstanceView::valuesChanged(const ValuesChangedCommand &command)
 {
     if (!model())
@@ -1044,7 +1061,7 @@ void NodeInstanceView::valuesChanged(const ValuesChangedCommand &command)
 
     QList<QPair<ModelNode, QString> > valuePropertyChangeList;
 
-    foreach(const PropertyValueContainer &container, command.valueChanges()) {
+    foreach (const PropertyValueContainer &container, command.valueChanges()) {
         if (hasInstanceForId(container.instanceId())) {
             NodeInstance instance = instanceForId(container.instanceId());
             if (instance.isValid()) {
@@ -1054,6 +1071,8 @@ void NodeInstanceView::valuesChanged(const ValuesChangedCommand &command)
         }
     }
 
+    nodeInstanceServer()->removeSharedMemory(createRemoveSharedMemoryCommand(QLatin1String("Values"), command.keyNumber()));
+
     if (!valuePropertyChangeList.isEmpty())
         emitInstancePropertyChange(valuePropertyChangeList);
 }
@@ -1120,7 +1139,16 @@ void NodeInstanceView::setPathToQt(const QString &pathToQt)
 {
     if (m_pathToQt != pathToQt) {
         m_pathToQt = pathToQt;
-        restartProcess();
+
+        /* The restart is done delayed, because when creating a new project we switch to that project
+         * before we open the new file. This means the user can get an error about a missing puppet,
+         * because the new project is based on another Qt version.
+         *
+         * See QTCREATORBUG-8756 for more details.
+         *
+         */
+
+        restartProcessDelayed();
     }
 }
 
@@ -1132,7 +1160,7 @@ void NodeInstanceView::statePreviewImagesChanged(const StatePreviewImageChangedC
   QVector<ModelNode> previewImageChangeVector;
 
   foreach (const ImageContainer &container, command.previews()) {
-      if (container.instanceId() == 0) {
+      if (container.keyNumber() == -1) {
           m_baseStatePreviewImage = container.image();
           previewImageChangeVector.append(rootModelNode());
       } else if (hasInstanceForId(container.instanceId())) {
@@ -1153,10 +1181,9 @@ void NodeInstanceView::componentCompleted(const ComponentCompletedCommand &comma
 
     QVector<ModelNode> nodeVector;
 
-    foreach(const qint32 &instanceId, command.instances()) {
-        if (hasModelNodeForInternalId(instanceId)) {
+    foreach (const qint32 &instanceId, command.instances()) {
+        if (hasModelNodeForInternalId(instanceId))
             nodeVector.append(modelNodeForInternalId(instanceId));
-        }
     }
 
     if (!nodeVector.isEmpty())
@@ -1171,7 +1198,7 @@ void NodeInstanceView::childrenChanged(const ChildrenChangedCommand &command)
 
     QVector<ModelNode> childNodeVector;
 
-    foreach(qint32 instanceId, command.childrenInstances()) {
+    foreach (qint32 instanceId, command.childrenInstances()) {
         if (hasInstanceForId(instanceId)) {
             NodeInstance instance = instanceForId(instanceId);
             instance.setParentId(command.parentInstanceId());
@@ -1196,15 +1223,18 @@ void NodeInstanceView::token(const TokenCommand &command)
     QVector<ModelNode> nodeVector;
 
     foreach (const qint32 &instanceId, command.instances()) {
-        if (hasModelNodeForInternalId(instanceId)) {
+        if (hasModelNodeForInternalId(instanceId))
             nodeVector.append(modelNodeForInternalId(instanceId));
-        }
     }
 
 
     emitInstanceToken(command.tokenName(), command.tokenNumber(), nodeVector);
 }
 
+void NodeInstanceView::debugOutput(const DebugOutputCommand & /*command*/)
+{
+}
+
 void NodeInstanceView::sendToken(const QString &token, int number, const QVector<ModelNode> &nodeVector)
 {
     QVector<qint32> instanceIdVector;
@@ -1214,4 +1244,9 @@ void NodeInstanceView::sendToken(const QString &token, int number, const QVector
     nodeInstanceServer()->token(TokenCommand(token, number, instanceIdVector));
 }
 
+QWidget *NodeInstanceView::widget()
+{
+    return 0;
+}
+
 }
