@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -61,9 +61,8 @@ void BaseTextMarkRegistry::add(BaseTextMark *mark)
     foreach (Core::IEditor *editor, em->editorsForFileName(mark->fileName())) {
         if (ITextEditor *textEditor = qobject_cast<ITextEditor *>(editor)) {
             ITextMarkable *markableInterface = textEditor->markableInterface();
-            if (markableInterface->addMark(mark)) {
+            if (markableInterface->addMark(mark))
                 break;
-            }
         }
     }
 }
