@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -39,11 +39,13 @@ using namespace CPlusPlus;
 
 #define VERIFY_ERRORS() \
     do { \
-      QFile e(testdata(errorFile)); \
       QByteArray expectedErrors; \
-      if (e.open(QFile::ReadOnly)) \
-        expectedErrors = QTextStream(&e).readAll().toUtf8(); \
-      QCOMPARE(errors, expectedErrors); \
+      if (!errorFile.isEmpty()) { \
+        QFile e(testdata(errorFile)); \
+        if (e.open(QFile::ReadOnly)) \
+          expectedErrors = QTextStream(&e).readAll().toUtf8(); \
+      } \
+      QCOMPARE(QString::fromLatin1(errors), QString::fromLatin1(expectedErrors)); \
     } while (0)
 
 
@@ -56,7 +58,8 @@ class tst_cxx11: public QObject
     */
     static QString testdata(const QString &name = QString())
     {
-        static const QString dataDirectory = QDir::currentPath() + QLatin1String("/data");
+        static const QString dataDirectory = QLatin1String(SRCDIR "/data");
+
         QString result = dataDirectory;
         if (!name.isEmpty()) {
             result += QLatin1Char('/');
@@ -105,6 +108,8 @@ class tst_cxx11: public QObject
             doc->translationUnit()->setCxxOxEnabled(true);
             doc->check();
             doc->control()->setDiagnosticClient(0);
+        } else {
+            qWarning() << "could not read file" << fileName;
         }
         return doc;
     }
@@ -113,12 +118,8 @@ private Q_SLOTS:
     //
     // checks for the syntax
     //
-    void inlineNamespace_data();
-    void inlineNamespace();
-    void staticAssert();
-    void staticAssert_data();
-    void noExcept();
-    void noExcept_data();
+    void parse_data();
+    void parse();
 
     //
     // checks for the semantic
@@ -127,15 +128,29 @@ private Q_SLOTS:
 };
 
 
-void tst_cxx11::inlineNamespace_data()
+void tst_cxx11::parse_data()
 {
     QTest::addColumn<QString>("file");
     QTest::addColumn<QString>("errorFile");
 
     QTest::newRow("inlineNamespace.1") << "inlineNamespace.1.cpp" << "inlineNamespace.1.errors.txt";
+    QTest::newRow("staticAssert.1") << "staticAssert.1.cpp" << "staticAssert.1.errors.txt";
+    QTest::newRow("noExcept.1") << "noExcept.1.cpp" << "noExcept.1.errors.txt";
+    QTest::newRow("braceInitializers.1") << "braceInitializers.1.cpp" << "braceInitializers.1.errors.txt";
+    QTest::newRow("braceInitializers.2") << "braceInitializers.2.cpp" << "";
+    QTest::newRow("braceInitializers.3") << "braceInitializers.3.cpp" << "";
+    QTest::newRow("defaultdeleteInitializer.1") << "defaultdeleteInitializer.1.cpp" << "";
+    QTest::newRow("refQualifier.1") << "refQualifier.1.cpp" << "";
+    QTest::newRow("alignofAlignas.1") << "alignofAlignas.1.cpp" << "";
+    QTest::newRow("rangeFor.1") << "rangeFor.1.cpp" << "";
+    QTest::newRow("aliasDecl.1") << "aliasDecl.1.cpp" << "";
+    QTest::newRow("enums.1") << "enums.1.cpp" << "";
+    QTest::newRow("templateGreaterGreater.1") << "templateGreaterGreater.1.cpp" << "";
+    QTest::newRow("packExpansion.1") << "packExpansion.1.cpp" << "";
+    QTest::newRow("declType.1") << "declType.1.cpp" << "";
 }
 
-void tst_cxx11::inlineNamespace()
+void tst_cxx11::parse()
 {
     QFETCH(QString, file);
     QFETCH(QString, errorFile);
@@ -165,49 +180,5 @@ void tst_cxx11::inlineNamespaceLookup()
     QCOMPARE(results.size(), 1); // the symbol is visible from the global scope
 }
 
-void tst_cxx11::staticAssert_data()
-{
-    QTest::addColumn<QString>("file");
-    QTest::addColumn<QString>("errorFile");
-
-    QTest::newRow("staticAssert.1") << "staticAssert.1.cpp" << "staticAssert.1.errors.txt";
-}
-
-void tst_cxx11::staticAssert()
-{
-    QFETCH(QString, file);
-    QFETCH(QString, errorFile);
-
-    QByteArray errors;
-    Document::Ptr doc = document(file, &errors);
-
-    if (! qgetenv("DEBUG").isNull())
-        printf("%s\n", errors.constData());
-
-    VERIFY_ERRORS();
-}
-
-void tst_cxx11::noExcept_data()
-{
-    QTest::addColumn<QString>("file");
-    QTest::addColumn<QString>("errorFile");
-
-    QTest::newRow("noExcept.1") << "noExcept.1.cpp" << "noExcept.1.errors.txt";
-}
-
-void tst_cxx11::noExcept()
-{
-    QFETCH(QString, file);
-    QFETCH(QString, errorFile);
-
-    QByteArray errors;
-    Document::Ptr doc = document(file, &errors);
-
-    if (! qgetenv("DEBUG").isNull())
-        printf("%s\n", errors.constData());
-
-    VERIFY_ERRORS();
-}
-
 QTEST_APPLESS_MAIN(tst_cxx11)
 #include "tst_cxx11.moc"
