@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -39,7 +39,7 @@ using namespace CPlusPlus;
 
 QByteArray loadSource(const QString &fileName)
 {
-    QFile inf(fileName);
+    QFile inf(QLatin1String(SRCDIR) + QLatin1Char('/') + fileName);
     if (!inf.open(QIODevice::ReadOnly | QIODevice::Text)) {
         qDebug("Cannot open \"%s\"", fileName.toUtf8().constData());
         return QByteArray();
@@ -53,7 +53,7 @@ QByteArray loadSource(const QString &fileName)
 
 void saveData(const QByteArray &data, const QString &fileName)
 {
-    QFile inf(fileName);
+    QFile inf(QLatin1String(SRCDIR) + QLatin1Char('/') + fileName);
     if (!inf.open(QIODevice::WriteOnly | QIODevice::Text)) {
         qDebug("Cannot open \"%s\"", fileName.toUtf8().constData());
         return;
@@ -216,6 +216,12 @@ public:
         *m_output = m_pp.run(fileName, src, nolines, true);
     }
 
+    virtual void markAsIncludeGuard(const QByteArray &macroName)
+    { m_includeGuardMacro = macroName; }
+
+    QByteArray includeGuard() const
+    { return m_includeGuardMacro; }
+
     QList<Block> skippedBlocks() const
     { return m_skippedBlocks; }
 
@@ -246,6 +252,7 @@ private:
     Preprocessor m_pp;
     QList<QDir> m_includePaths;
     unsigned m_includeDepth;
+    QByteArray m_includeGuardMacro;
     QList<Block> m_skippedBlocks;
     QList<Include> m_recordedIncludes;
     QList<QByteArray> m_expandedMacros;
@@ -329,6 +336,7 @@ private slots:
     void dont_eagerly_expand_data();
     void comparisons_data();
     void comparisons();
+    void comments_before_args();
     void comments_within();
     void comments_within_data();
     void comments_within2();
@@ -339,6 +347,8 @@ private slots:
     void multiline_strings_data();
     void skip_unknown_directives();
     void skip_unknown_directives_data();
+    void include_guard();
+    void include_guard_data();
 };
 
 // Remove all #... lines, and 'simplify' string, to allow easily comparing the result
@@ -1239,6 +1249,28 @@ void tst_Preprocessor::comments_within_data()
     QTest::newRow("case 7") << original << expected;
 }
 
+void tst_Preprocessor::comments_before_args()
+{
+    Client *client = 0; // no client.
+    Environment env;
+
+    Preprocessor preprocess(client, &env);
+    preprocess.setKeepComments(true);
+    QByteArray preprocessed = preprocess.run(QLatin1String("<stdin>"),
+                                                "\n#define foo(a,b) int a = b;"
+                                                "\nfoo/*C comment*/(a,1)\n"
+                                                "\nfoo/**Doxygen comment*/(b,2)\n"
+                                                "\nfoo//C++ comment\n(c,3)\n"
+                                                "\nfoo///Doxygen C++ comment\n(d,4)\n"
+                                                "\nfoo/*multiple*///comments\n/**as well*/(e,5)\n",
+                                             true, false);
+
+    preprocessed = preprocessed.simplified();
+//    DUMP_OUTPUT(preprocessed);
+    QCOMPARE(simplified(preprocessed),
+             QString("int a=1;int b=2;int c=3;int d=4;int e=5;"));
+}
+
 void tst_Preprocessor::comments_within2()
 {
     compare_input_output(true);
@@ -1458,6 +1490,88 @@ void tst_Preprocessor::skip_unknown_directives_data()
     QTest::newRow("case 1") << original << expected;
 }
 
+void tst_Preprocessor::include_guard()
+{
+    QFETCH(QString, includeGuard);
+    QFETCH(QString, input);
+
+    QByteArray output;
+    Environment env;
+    MockClient client(&env, &output);
+    Preprocessor preprocess(&client, &env);
+    preprocess.setKeepComments(true);
+    /*QByteArray prep =*/ preprocess.run(QLatin1String("<test-case>"), input);
+    QCOMPARE(QString::fromUtf8(client.includeGuard()), includeGuard);
+}
+
+void tst_Preprocessor::include_guard_data()
+{
+    QTest::addColumn<QString>("includeGuard");
+    QTest::addColumn<QString>("input");
+
+    QTest::newRow("basic-test") << "BASIC_TEST"
+                                << "#ifndef BASIC_TEST\n"
+                                   "#define BASIC_TEST\n"
+                                   "\n"
+                                   "#endif // BASIC_TEST\n";
+    QTest::newRow("comments-1") << "GUARD"
+                                << "/* some\n"
+                                   " * copyright\n"
+                                   " * header.\n"
+                                   " */\n"
+                                   "#ifndef GUARD\n"
+                                   "#define GUARD\n"
+                                   "\n"
+                                   "#endif // GUARD\n";
+    QTest::newRow("comments-2") << "GUARD"
+                                << "#ifndef GUARD\n"
+                                   "#define GUARD\n"
+                                   "\n"
+                                   "#endif // GUARD\n"
+                                   "/* some\n"
+                                   " * trailing\n"
+                                   " * comments.\n"
+                                   " */\n"
+                                   ;
+    QTest::newRow("nested-ifdef") << "GUARD"
+                                  << "#ifndef GUARD\n"
+                                     "#define GUARD\n"
+                                     "#ifndef NOT_GUARD\n"
+                                     "#define NOT_GUARD\n"
+                                     "#endif // NOT_GUARD\n"
+                                     "\n"
+                                     "#endif // GUARD\n"
+                                     ;
+    QTest::newRow("leading-tokens") << ""
+                                    << "int i;\n"
+                                       "#ifndef GUARD\n"
+                                       "#define GUARD\n"
+                                       "\n"
+                                       "#endif // GUARD\n"
+                                       ;
+    QTest::newRow("trailing-tokens") << ""
+                                     << "#ifndef GUARD\n"
+                                        "#define GUARD\n"
+                                        "\n"
+                                        "#endif // GUARD\n"
+                                        "int i;\n"
+                                        ;
+    QTest::newRow("surprising-but-correct") << "GUARD"
+                                            << "#ifndef GUARD\n"
+                                               "int i;\n"
+                                               "\n"
+                                               "#define GUARD\n"
+                                               "#endif // GUARD\n"
+                                               ;
+    QTest::newRow("incomplete-1") << ""
+                                  << "#ifndef GUARD\n"
+                                     ;
+    QTest::newRow("incomplete-2") << "GUARD"
+                                  << "#ifndef GUARD\n"
+                                     "#define GUARD\n"
+                                     ;
+}
+
 void tst_Preprocessor::compare_input_output(bool keepComments)
 {
     QFETCH(QByteArray, input);
